![Project logo](https://github.com/urosjarc/maestro/blob/master/docs/media/header.png?raw=true)

<br>

[![pip][pip]][pip-url]
[![travis][travis]][travis-url]
[![coverage][coverage]][coverage-url]
[![dependencies][dep]][dep-url]
[![codestyle][codestyle]][codestyle-url]
[![docs][docs]][docs-url]
[![chat][chat]][chat-url]

> Music practice on steroids.

[![Patreon User][support]][support-url]
[![Twitter User][twitter]][twitter-url]

[pip]: https://img.shields.io/npm/v/generator-generator2.svg
[pip-url]: https://www.npmjs.com/package/generator-generator2
[travis]: https://img.shields.io/travis/urosjarc/maestro.svg
[travis-url]: https://travis-ci.org/urosjarc/maestro
[coverage]: https://img.shields.io/codacy/coverage/71b26bbc68de46ed9b6ad037d821b635.svg
[coverage-url]: https://www.codacy.com/app/urosjarc/maestro
[codestyle]: https://img.shields.io/codacy/grade/71b26bbc68de46ed9b6ad037d821b635.svg
[codestyle-url]: https://www.codacy.com/app/urosjarc/maestro
[dep]: https://img.shields.io/david/urosjarc/maestro.svg
[dep-url]: https://david-dm.org/urosjarc/maestro
[docs]: http://inch-ci.org/github/urosjarc/maestro.svg?style=shields
[docs-url]: http://inch-ci.org/github/urosjarc/maestro
[chat]: https://badges.gitter.im/Join%20Chat.svg
[chat-url]: https://gitter.im/urosjarc/maestro?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
[support]: https://img.shields.io/badge/patreon-urosjarc-green.svg?style=social
[support-url]: https://patreon.com/urosjarc/
[twitter]: https://img.shields.io/twitter/follow/urosjarc.svg?style=social&label=follow
[twitter-url]: https://twitter.com/intent/follow?screen_name=urosjarc

<br>

## <font color=red>Warning</font>
Project is still in development!
Please see project [milestones](https://github.com/urosjarc/maestro/milestones)
to see when the first production ready version will come out.

<br>

## Description

Maestro will help you develop similar skill as blind typing on computer
keyboard but on your music instrument. Maestro practice will be on **moving** music
note track with generated random notes. While player will try to
play those notes, Maestro will check frequency of the sound and compare
it with notes on music track (notes must be calibrated before). Base on that checking Maestro will make
final score at the end of playing session and create players statistics and weak spots
which player can fix and practice on.

<br>

## Homepage
For more informations please visit projects official homepage.
> [https://urosjarc.github.io/maestro](https://urosjarc.github.io/maestro)

<br>

## License
Copyright © 2016 Uroš Jarc

MIT License
